@@ -4,7 +4,7 @@ import numpy as np
 from scipy.stats import expon
 
 from xgboost_distribution.distributions.base import BaseDistribution
-from xgboost_distribution.distributions.utils import check_is_ge_zero
+from xgboost_distribution.distributions.utils import check_all_ge_zero
 
 
 class Exponential(BaseDistribution):
@@ -33,7 +33,7 @@ class Exponential(BaseDistribution):
         return ("scale",)
 
     def check_target(self, y):
-        check_is_ge_zero(y)
+        check_all_ge_zero(y)
 
     def gradient_and_hessian(self, y, params, natural_gradient=True):
         """Gradient and diagonal hessian"""
@@ -54,11 +54,11 @@ class Exponential(BaseDistribution):
         return grad, hess
 
     def loss(self, y, params):
-        scale = self.predict(params)
-        return "Exponential-NLL", -expon.logpdf(y, scale=scale).mean()
+        (scale,) = self.predict(params)
+        return "Exponential-NLL", -expon.logpdf(y, scale=scale)
 
     def predict(self, params):
-        log_scale = params
+        log_scale = params  # params are shape (n,)
         scale = np.exp(log_scale)
         return self.Predictions(scale=scale)
 
