@@ -81,11 +81,12 @@ class Normal(BaseDistribution):
 
     def loss(self, y, params):
         loc, scale = self.predict(params)
-        return "NormalDistribution-NLL", -norm.logpdf(y, loc=loc, scale=scale).mean()
+        return "NormalDistribution-NLL", -norm.logpdf(y, loc=loc, scale=scale)
 
     def predict(self, params):
         loc, log_scale = self._split_params(params)
-        # log_scale = np.clip(log_scale, -100, 100)  # TODO: is this needed?
+        # TODO: do we need clipping for safety?
+        # log_scale = np.clip(log_scale, -100, 100)
         scale = np.exp(log_scale)
 
         return self.Predictions(loc=loc, scale=scale)
