@@ -4,9 +4,9 @@ import numpy as np
 import pandas as pd
 
 from xgboost_distribution.distributions.utils import (
-    check_is_ge_zero,
-    check_is_gt_zero,
-    check_is_integer,
+    check_all_ge_zero,
+    check_all_gt_zero,
+    check_all_integer,
 )
 
 
@@ -15,7 +15,7 @@ from xgboost_distribution.distributions.utils import (
     [np.array([0, 1]), pd.Series([-1, 0, 2])],
 )
 def test_check_is_integer(x):
-    check_is_integer(x)
+    check_all_integer(x)
 
 
 @pytest.mark.parametrize(
@@ -24,7 +24,7 @@ def test_check_is_integer(x):
 )
 def test_check_is_integer_raises(x):
     with pytest.raises(ValueError):
-        check_is_integer(x)
+        check_all_integer(x)
 
 
 @pytest.mark.parametrize(
@@ -32,7 +32,7 @@ def test_check_is_integer_raises(x):
     [np.array([0, 1]), pd.Series([0, 1.2, 2])],
 )
 def test_check_is_ge_zero(x):
-    check_is_ge_zero(x)
+    check_all_ge_zero(x)
 
 
 @pytest.mark.parametrize(
@@ -41,7 +41,7 @@ def test_check_is_ge_zero(x):
 )
 def test_check_is_ge_zero_raises(x):
     with pytest.raises(ValueError):
-        check_is_ge_zero(x)
+        check_all_ge_zero(x)
 
 
 @pytest.mark.parametrize(
@@ -49,7 +49,7 @@ def test_check_is_ge_zero_raises(x):
     [np.array([1, 2]), pd.Series([0.1, 1.2, 2.2])],
 )
 def test_check_is_gt_zero(x):
-    check_is_gt_zero(x)
+    check_all_gt_zero(x)
 
 
 @pytest.mark.parametrize(
@@ -58,4 +58,4 @@ def test_check_is_gt_zero(x):
 )
 def test_check_is_gt_zero_raises(x):
     with pytest.raises(ValueError):
-        check_is_gt_zero(x)
+        check_all_gt_zero(x)
